LANG

Enum LANG 

pub enum LANG {
    Javascript,
    Java,
    Kotlin,
    Rust,
    Cpp,
    Python,
    Tsx,
    Typescript,
    Ccomment,
    Preproc,
}
The list of supported languages.

Variants



Javascript

The JavaScript language



Java

The Java language



Kotlin

The Kotlin language



Rust

The Rust language



Cpp

The C/C++ language



Python

The Python language



Tsx

The Tsx language incorporates the JSX syntax inside TypeScript



Typescript

The TypeScript language



Ccomment

The Ccomment language is a variant of the C language focused on comments



Preproc

The PreProc language is a variant of the C/C++ language focused on macros

Implementations

Source

impl LANG

pub fn into_enum_iter() -> impl Iterator<Item = LANG>

Return an iterator over the supported languages.

Examples
use rust_code_analysis::LANG;

for lang in LANG::into_enum_iter() {
    println!("{:?}", lang);
}
pub fn get_name(&self) -> &'static str

Returns the name of a language as a &str.

Examples
use rust_code_analysis::LANG;

println!("{}", LANG::Rust.get_name());